@@ -193,7 +193,7 @@ static DviCharNameMap ISO8859_1_map = {
 {	":",			/* 58 */},
 {	";",			/* 59 */},
 {	"<",			/* 60 */},
-{	"=", "eq",		/* 61 */},
+{	"=",			/* 61 */},
 {	">",			/* 62 */},
 {	"?",			/* 63 */},
 {	"@", "at",		/* 64 */},
@@ -226,7 +226,7 @@ static DviCharNameMap ISO8859_1_map = {
 {	"[", "lB",		/* 91 */},
 {	"\\", "rs",		/* 92 */},
 {	"]", "rB",		/* 93 */},
-{	"^", "a^", "ha"		/* 94 */},
+{	"^", "a^", "ha",	/* 94 */},
 {	"_",			/* 95 */},
 {	"`", "oq",		/* 96 */},
 {	"a",			/* 97 */},
@@ -256,9 +256,9 @@ static DviCharNameMap ISO8859_1_map = {
 {	"y",			/* 121 */},
 {	"z",			/* 122 */},
 {	"{", "lC",		/* 123 */},
-{	"|", "or", "ba"		/* 124 */},
+{	"|", "ba",		/* 124 */},
 {	"}", "rC",		/* 125 */},
-{	"~", "a~", "ap", "ti"	/* 126 */},
+{	"~", "a~", "ti",	/* 126 */},
 {	0,			/* 127 */},
 {	0,			/* 128 */},
 {	0,			/* 129 */},
@@ -304,7 +304,7 @@ static DviCharNameMap ISO8859_1_map = {
 {	"co",			/* 169 */},
 {	"Of",			/* 170 */},
 {	"Fo",			/* 171 */},
-{	"no",			/* 172 */},
+{	"tno",			/* 172 */},
 {	"-", "hy",		/* 173 */},
 {	"rg",			/* 174 */},
 {	"a-",			/* 175 */},
@@ -394,262 +394,262 @@ static DviCharNameMap Adobe_Symbol_map = {
 	"adobe-fontspecific",
 	1,
 {
-{	0,					/* 0 */},
-{	0,					/* 1 */},
-{	0,					/* 2 */},
-{	0,					/* 3 */},
-{	0,					/* 4 */},
-{	0,					/* 5 */},
-{	0,					/* 6 */},
-{	0,					/* 7 */},
-{	0,					/* 8 */},
-{	0,					/* 9 */},
-{	0,					/* 10 */},
-{	0,					/* 11 */},
-{	0,					/* 12 */},
-{	0,					/* 13 */},
-{	0,					/* 14 */},
-{	0,					/* 15 */},
-{	0,					/* 16 */},
-{	0,					/* 17 */},
-{	0,					/* 18 */},
-{	0,					/* 19 */},
-{	0,					/* 20 */},
-{	0,					/* 21 */},
-{	0,					/* 22 */},
-{	0,					/* 23 */},
-{	0,					/* 24 */},
-{	0,					/* 25 */},
-{	0,					/* 26 */},
-{	0,					/* 27 */},
-{	0,					/* 28 */},
-{	0,					/* 29 */},
-{	0,					/* 30 */},
-{	0,					/* 31 */},
-{	0,					/* 32 */},
-{	"!",					/* 33 */},
-{	"fa",					/* 34 */},
-{	"#", "sh",				/* 35 */},
-{	"te",					/* 36 */},
-{	"%",					/* 37 */},
-{	"&",					/* 38 */},
-{	"st",					/* 39 */},
-{	"(",					/* 40 */},
-{	")",					/* 41 */},
-{	"**",					/* 42 */},
-{	"+", "pl",				/* 43 */},
-{	",",					/* 44 */},
-{	"\\-", "mi",				/* 45 */},
-{	".",					/* 46 */},
-{	"/", "sl",				/* 47 */},
-{	"0",					/* 48 */},
-{	"1",					/* 49 */},
-{	"2",					/* 50 */},
-{	"3",					/* 51 */},
-{	"4",					/* 52 */},
-{	"5",					/* 53 */},
-{	"6",					/* 54 */},
-{	"7",					/* 55 */},
-{	"8",					/* 56 */},
-{	"9",					/* 57 */},
-{	":",					/* 58 */},
-{	";",					/* 59 */},
-{	"<",					/* 60 */},
-{	"=", "eq",				/* 61 */},
-{	">",					/* 62 */},
-{	"?",					/* 63 */},
-{	"=~",					/* 64 */},
-{	"*A",					/* 65 */},
-{	"*B",					/* 66 */},
-{	"*X",					/* 67 */},
-{	"*D",					/* 68 */},
-{	"*E",					/* 69 */},
-{	"*F",					/* 70 */},
-{	"*G",					/* 71 */},
-{	"*Y",					/* 72 */},
-{	"*I",					/* 73 */},
-{	"+h",					/* 74 */},
-{	"*K",					/* 75 */},
-{	"*L",					/* 76 */},
-{	"*M",					/* 77 */},
-{	"*N",					/* 78 */},
-{	"*O",					/* 79 */},
-{	"*P",					/* 80 */},
-{	"*H",					/* 81 */},
-{	"*R",					/* 82 */},
-{	"*S",					/* 83 */},
-{	"*T",					/* 84 */},
-{	0,					/* 85 */},
-{	"ts",					/* 86 */},
-{	"*W",					/* 87 */},
-{	"*C",					/* 88 */},
-{	"*Q",					/* 89 */},
-{	"*Z",					/* 90 */},
-{	"[", "lB",				/* 91 */},
-{	"tf", "3d",				/* 92 */},
-{	"]", "rB",				/* 93 */},
-{	"pp",					/* 94 */},
-{	"_",					/* 95 */},
-{	"radicalex",				/* 96 */},
-{	"*a",					/* 97 */},
-{	"*b",					/* 98 */},
-{	"*x",					/* 99 */},
-{	"*d",					/* 100 */},
-{	"*e",					/* 101 */},
-{	"*f",					/* 102 */},
-{	"*g",					/* 103 */},
-{	"*y",					/* 104 */},
-{	"*i",					/* 105 */},
-{	"+f",					/* 106 */},
-{	"*k",					/* 107 */},
-{	"*l",					/* 108 */},
-{	"*m",					/* 109 */},
-{	"*n",					/* 110 */},
-{	"*o",					/* 111 */},
-{	"*p",					/* 112 */},
-{	"*h",					/* 113 */},
-{	"*r",					/* 114 */},
-{	"*s",					/* 115 */},
-{	"*t",					/* 116 */},
-{	"*u",					/* 117 */},
-{	"+p",					/* 118 */},
-{	"*w",					/* 119 */},
-{	"*c",					/* 120 */},
-{	"*q",					/* 121 */},
-{	"*z",					/* 122 */},
-{	"lC", "{",				/* 123 */},
-{	"ba", "or", "|",			/* 124 */},
-{	"rC", "}",				/* 125 */},
-{	"ap",					/* 126 */},
-{	0,					/* 127 */},
-{	0,					/* 128 */},
-{	0,					/* 129 */},
-{	0,					/* 130 */},
-{	0,					/* 131 */},
-{	0,					/* 132 */},
-{	0,					/* 133 */},
-{	0,					/* 134 */},
-{	0,					/* 135 */},
-{	0,					/* 136 */},
-{	0,					/* 137 */},
-{	0,					/* 138 */},
-{	0,					/* 139 */},
-{	0,					/* 140 */},
-{	0,					/* 141 */},
-{	0,					/* 142 */},
-{	0,					/* 143 */},
-{	0,					/* 144 */},
-{	0,					/* 145 */},
-{	0,					/* 146 */},
-{	0,					/* 147 */},
-{	0,					/* 148 */},
-{	0,					/* 149 */},
-{	0,					/* 150 */},
-{	0,					/* 151 */},
-{	0,					/* 152 */},
-{	0,					/* 153 */},
-{	0,					/* 154 */},
-{	0,					/* 155 */},
-{	0,					/* 156 */},
-{	0,					/* 157 */},
-{	0,					/* 158 */},
-{	0,					/* 159 */},
-{	0,					/* 160 */},
-{	"*U",					/* 161 */},
-{	"fm",					/* 162 */},
-{	"<=",					/* 163 */},
-{	"f/",					/* 164 */},
-{	"if",					/* 165 */},
-{	"Fn",					/* 166 */},
-{	"CL",					/* 167 */},
-{	"DI",					/* 168 */},
-{	"HE",					/* 169 */},
-{	"SP",					/* 170 */},
-{	"<>",					/* 171 */},
-{	"<-",					/* 172 */},
-{	"ua", "arrowverttp",			/* 173 */},
-{	"->",					/* 174 */},
-{	"da", "arrowvertbt",			/* 175 */},
-{	"de",					/* 176 */},
-{	"+-",					/* 177 */},
-{	"sd",					/* 178 */},
-{	">=",					/* 179 */},
-{	"mu",					/* 180 */},
-{	"pt",					/* 181 */},
-{	"pd",					/* 182 */},
-{	"bu",					/* 183 */},
-{	"di",					/* 184 */},
-{	"!=",					/* 185 */},
-{	"==",					/* 186 */},
-{	"~=", "~~",				/* 187 */},
-{	0,					/* 188 */},
-{	"arrowvertex",				/* 189 */},
-{	"an",					/* 190 */},
-{	"CR",					/* 191 */},
-{	"Ah",					/* 192 */},
-{	"Im",					/* 193 */},
-{	"Re",					/* 194 */},
-{	"wp",					/* 195 */},
-{	"c*",					/* 196 */},
-{	"c+",					/* 197 */},
-{	"es",					/* 198 */},
-{	"ca",					/* 199 */},
-{	"cu",					/* 200 */},
-{	"sp",					/* 201 */},
-{	"ip",					/* 202 */},
-{	"nb",					/* 203 */},
-{	"sb",					/* 204 */},
-{	"ib",					/* 205 */},
-{	"mo",					/* 206 */},
-{	"nm",					/* 207 */},
-{	"/_",					/* 208 */},
-{	"gr",					/* 209 */},
-{	"rg",					/* 210 */},
-{	"co",					/* 211 */},
-{	"tm",					/* 212 */},
-{	0,					/* 213 */},
-{	"sr",					/* 214 */},
-{	"md",					/* 215 */},
-{	"no",					/* 216 */},
-{	"AN",					/* 217 */},
-{	"OR",					/* 218 */},
-{	"hA",					/* 219 */},
-{	"lA",					/* 220 */},
-{	"uA",					/* 221 */},
-{	"rA",					/* 222 */},
-{	"dA",					/* 223 */},
-{	"lz",					/* 224 */},
-{	"la",					/* 225 */},
-{	0,					/* 226 */},
-{	0,					/* 227 */},
-{	0,					/* 228 */},
-{	0,					/* 229 */},
-{	"parenlefttp",				/* 230 */},
-{	"parenleftex",				/* 231 */},
-{	"parenleftbt",				/* 232 */},
-{	"bracketlefttp", "lc",			/* 233 */},
-{	"bracketleftex",			/* 234 */},
-{	"bracketleftbt", "lf",			/* 235 */},
-{	"bracelefttp", "lt",			/* 236 */},
-{	"braceleftmid", "lk",			/* 237 */},
-{	"braceleftbt", "lb",			/* 238 */},
-{	"bracerightex", "braceleftex", "bv",	/* 239 */},
-{	0,					/* 240 */},
-{	"ra",					/* 241 */},
-{	"is",					/* 242 */},
-{	0,					/* 243 */},
-{	0,					/* 244 */},
-{	0,					/* 245 */},
-{	"parenrighttp",				/* 246 */},
-{	"parenrightex",				/* 247 */},
-{	"parenrightbt",				/* 248 */},
-{	"bracketrighttp", "rc",			/* 249 */},
-{	"bracketrightex",			/* 250 */},
-{	"bracketrightbt", "rf",			/* 251 */},
-{	"bracerighttp", "rt",			/* 252 */},
-{	"bracerightmid", "rk",			/* 253 */},
-{	"bracerightbt", "rb",			/* 254 */},
-{	0,					/* 255 */},
+{	0,						/* 0 */},
+{	0,						/* 1 */},
+{	0,						/* 2 */},
+{	0,						/* 3 */},
+{	0,						/* 4 */},
+{	0,						/* 5 */},
+{	0,						/* 6 */},
+{	0,						/* 7 */},
+{	0,						/* 8 */},
+{	0,						/* 9 */},
+{	0,						/* 10 */},
+{	0,						/* 11 */},
+{	0,						/* 12 */},
+{	0,						/* 13 */},
+{	0,						/* 14 */},
+{	0,						/* 15 */},
+{	0,						/* 16 */},
+{	0,						/* 17 */},
+{	0,						/* 18 */},
+{	0,						/* 19 */},
+{	0,						/* 20 */},
+{	0,						/* 21 */},
+{	0,						/* 22 */},
+{	0,						/* 23 */},
+{	0,						/* 24 */},
+{	0,						/* 25 */},
+{	0,						/* 26 */},
+{	0,						/* 27 */},
+{	0,						/* 28 */},
+{	0,						/* 29 */},
+{	0,						/* 30 */},
+{	0,						/* 31 */},
+{	0,						/* 32 */},
+{	"!",						/* 33 */},
+{	"fa",						/* 34 */},
+{	"#", "sh",					/* 35 */},
+{	"te",						/* 36 */},
+{	"%",						/* 37 */},
+{	"&",						/* 38 */},
+{	"st",						/* 39 */},
+{	"(",						/* 40 */},
+{	")",						/* 41 */},
+{	"**",						/* 42 */},
+{	"+", "pl",					/* 43 */},
+{	",",						/* 44 */},
+{	"\\-", "mi",					/* 45 */},
+{	".",						/* 46 */},
+{	"/", "sl",					/* 47 */},
+{	"0",						/* 48 */},
+{	"1",						/* 49 */},
+{	"2",						/* 50 */},
+{	"3",						/* 51 */},
+{	"4",						/* 52 */},
+{	"5",						/* 53 */},
+{	"6",						/* 54 */},
+{	"7",						/* 55 */},
+{	"8",						/* 56 */},
+{	"9",						/* 57 */},
+{	":",						/* 58 */},
+{	";",						/* 59 */},
+{	"<",						/* 60 */},
+{	"=", "eq",					/* 61 */},
+{	">",						/* 62 */},
+{	"?",						/* 63 */},
+{	"=~",						/* 64 */},
+{	"*A",						/* 65 */},
+{	"*B",						/* 66 */},
+{	"*X",						/* 67 */},
+{	"*D",						/* 68 */},
+{	"*E",						/* 69 */},
+{	"*F",						/* 70 */},
+{	"*G",						/* 71 */},
+{	"*Y",						/* 72 */},
+{	"*I",						/* 73 */},
+{	"+h",						/* 74 */},
+{	"*K",						/* 75 */},
+{	"*L",						/* 76 */},
+{	"*M",						/* 77 */},
+{	"*N",						/* 78 */},
+{	"*O",						/* 79 */},
+{	"*P",						/* 80 */},
+{	"*H",						/* 81 */},
+{	"*R",						/* 82 */},
+{	"*S",						/* 83 */},
+{	"*T",						/* 84 */},
+{	0,						/* 85 */},
+{	"ts",						/* 86 */},
+{	"*W",						/* 87 */},
+{	"*C",						/* 88 */},
+{	"*Q",						/* 89 */},
+{	"*Z",						/* 90 */},
+{	"[", "lB",					/* 91 */},
+{	"tf", "3d",					/* 92 */},
+{	"]", "rB",					/* 93 */},
+{	"pp",						/* 94 */},
+{	"_",						/* 95 */},
+{	"radicalex",					/* 96 */},
+{	"*a",						/* 97 */},
+{	"*b",						/* 98 */},
+{	"*x",						/* 99 */},
+{	"*d",						/* 100 */},
+{	"*e",						/* 101 */},
+{	"*f",						/* 102 */},
+{	"*g",						/* 103 */},
+{	"*y",						/* 104 */},
+{	"*i",						/* 105 */},
+{	"+f",						/* 106 */},
+{	"*k",						/* 107 */},
+{	"*l",						/* 108 */},
+{	"*m",						/* 109 */},
+{	"*n",						/* 110 */},
+{	"*o",						/* 111 */},
+{	"*p",						/* 112 */},
+{	"*h",						/* 113 */},
+{	"*r",						/* 114 */},
+{	"*s",						/* 115 */},
+{	"*t",						/* 116 */},
+{	"*u",						/* 117 */},
+{	"+p",						/* 118 */},
+{	"*w",						/* 119 */},
+{	"*c",						/* 120 */},
+{	"*q",						/* 121 */},
+{	"*z",						/* 122 */},
+{	"lC", "{",					/* 123 */},
+{	"ba", "|",					/* 124 */},
+{	"rC", "}",					/* 125 */},
+{	"ap",						/* 126 */},
+{	0,						/* 127 */},
+{	0,						/* 128 */},
+{	0,						/* 129 */},
+{	0,						/* 130 */},
+{	0,						/* 131 */},
+{	0,						/* 132 */},
+{	0,						/* 133 */},
+{	0,						/* 134 */},
+{	0,						/* 135 */},
+{	0,						/* 136 */},
+{	0,						/* 137 */},
+{	0,						/* 138 */},
+{	0,						/* 139 */},
+{	0,						/* 140 */},
+{	0,						/* 141 */},
+{	0,						/* 142 */},
+{	0,						/* 143 */},
+{	0,						/* 144 */},
+{	0,						/* 145 */},
+{	0,						/* 146 */},
+{	0,						/* 147 */},
+{	0,						/* 148 */},
+{	0,						/* 149 */},
+{	0,						/* 150 */},
+{	0,						/* 151 */},
+{	0,						/* 152 */},
+{	0,						/* 153 */},
+{	0,						/* 154 */},
+{	0,						/* 155 */},
+{	0,						/* 156 */},
+{	0,						/* 157 */},
+{	0,						/* 158 */},
+{	0,						/* 159 */},
+{	0,						/* 160 */},
+{	"*U",						/* 161 */},
+{	"fm",						/* 162 */},
+{	"<=",						/* 163 */},
+{	"f/",						/* 164 */},
+{	"if",						/* 165 */},
+{	"Fn",						/* 166 */},
+{	"CL",						/* 167 */},
+{	"DI",						/* 168 */},
+{	"HE",						/* 169 */},
+{	"SP",						/* 170 */},
+{	"<>",						/* 171 */},
+{	"<-",						/* 172 */},
+{	"ua", "arrowverttp",				/* 173 */},
+{	"->",						/* 174 */},
+{	"da", "arrowvertbt",				/* 175 */},
+{	"de",						/* 176 */},
+{	"+-",						/* 177 */},
+{	"sd",						/* 178 */},
+{	">=",						/* 179 */},
+{	"mu",						/* 180 */},
+{	"pt",						/* 181 */},
+{	"pd",						/* 182 */},
+{	"bu",						/* 183 */},
+{	"di",						/* 184 */},
+{	"!=",						/* 185 */},
+{	"==",						/* 186 */},
+{	"~=", "~~",					/* 187 */},
+{	0,						/* 188 */},
+{	"arrowvertex",					/* 189 */},
+{	"an",						/* 190 */},
+{	"CR",						/* 191 */},
+{	"Ah",						/* 192 */},
+{	"Im",						/* 193 */},
+{	"Re",						/* 194 */},
+{	"wp",						/* 195 */},
+{	"c*",						/* 196 */},
+{	"c+",						/* 197 */},
+{	"es",						/* 198 */},
+{	"ca",						/* 199 */},
+{	"cu",						/* 200 */},
+{	"sp",						/* 201 */},
+{	"ip",						/* 202 */},
+{	"nb",						/* 203 */},
+{	"sb",						/* 204 */},
+{	"ib",						/* 205 */},
+{	"mo",						/* 206 */},
+{	"nm",						/* 207 */},
+{	"/_",						/* 208 */},
+{	"gr",						/* 209 */},
+{	"rg",						/* 210 */},
+{	"co",						/* 211 */},
+{	"tm",						/* 212 */},
+{	0,						/* 213 */},
+{	"sr", "sqrt",					/* 214 */},
+{	"md",						/* 215 */},
+{	"no",						/* 216 */},
+{	"AN",						/* 217 */},
+{	"OR",						/* 218 */},
+{	"hA",						/* 219 */},
+{	"lA",						/* 220 */},
+{	"uA",						/* 221 */},
+{	"rA",						/* 222 */},
+{	"dA",						/* 223 */},
+{	"lz",						/* 224 */},
+{	"la",						/* 225 */},
+{	0,						/* 226 */},
+{	0,						/* 227 */},
+{	0,						/* 228 */},
+{	0,						/* 229 */},
+{	"parenlefttp",					/* 230 */},
+{	"parenleftex",					/* 231 */},
+{	"parenleftbt",					/* 232 */},
+{	"bracketlefttp", "lc",				/* 233 */},
+{	"bracketleftex",				/* 234 */},
+{	"bracketleftbt", "lf",				/* 235 */},
+{	"bracelefttp", "lt",				/* 236 */},
+{	"braceleftmid", "lk",				/* 237 */},
+{	"braceleftbt", "lb",				/* 238 */},
+{	"bracerightex", "braceleftex", "braceex", "bv",	/* 239 */},
+{	0,						/* 240 */},
+{	"ra",						/* 241 */},
+{	"is", "integral",				/* 242 */},
+{	0,						/* 243 */},
+{	0,						/* 244 */},
+{	0,						/* 245 */},
+{	"parenrighttp",					/* 246 */},
+{	"parenrightex",					/* 247 */},
+{	"parenrightbt",					/* 248 */},
+{	"bracketrighttp", "rc",				/* 249 */},
+{	"bracketrightex",				/* 250 */},
+{	"bracketrightbt", "rf",				/* 251 */},
+{	"bracerighttp", "rt",				/* 252 */},
+{	"bracerightmid", "rk",				/* 253 */},
+{	"bracerightbt", "rb",				/* 254 */},
+{	0,						/* 255 */},
 }};
 
 
